@@ -2,6 +2,7 @@ from pymatgen.electronic_structure.core import Spin, Orbital
 from pymatgen.io.vasp.outputs import BSVasprun, Eigenval
 from pymatgen.io.vasp.inputs import Kpoints, Poscar, Incar
 from pymatgen.symmetry.bandstructure import HighSymmKpath
+from pymatgen.core.periodic_table import Element
 from vaspvis.unfold import unfold, make_kpath, removeDuplicateKpoints
 from pymatgen.core.periodic_table import Element
 from pyprocar.utilsprocar import UtilsProcar
@@ -126,7 +127,7 @@ class Band:
 
         self.wavecar = os.path.join(folder, 'WAVECAR')
         self.projected = projected
-        self.forbitals = False
+        self.forbitals = self._check_f_orb()
         self.unfold = unfold
 
         if self.hse and self.unfold:
@@ -210,6 +211,19 @@ class Band:
 
         self.bg = bg
 
+    def _check_f_orb(self):
+        f = False
+        for element in self.poscar.site_symbols:
+            if element != 'H':
+                E = Element(element)
+                orbitals = list(E.atomic_orbitals.keys())
+                for orb in orbitals:
+                    if 'f' in orb:
+                        f = True
+        
+        return f
+                    
+
 
     def _load_bands(self):
         """
@@ -388,9 +402,6 @@ class Band:
             zero_weight = np.where(kpoint_weights == 0)[0]
             projected_eigenvalues = projected_eigenvalues[:,zero_weight]
 
-        if projected_eigenvalues.shape[-1] == 16:
-            self.forbitals = True
-
         projected_eigenvalues = np.square(projected_eigenvalues)
 
         return projected_eigenvalues
